@@ -1,5 +1,5 @@
 #!/usr/bin/python
-# $Id: wlink.py 1113 2014-11-14 05:04:51Z mwall $
+# $Id: wlink.py 1229 2015-01-27 20:16:18Z mwall $
 # Copyright 2014 Matthew Wall
 """weewx driver for WeatherLink web sites
    download data from a weatherlink site for use in weewx
@@ -46,9 +46,14 @@ import time
 import urllib2
 from HTMLParser import HTMLParser
 
+import weewx
 import weewx.drivers
 
-DRIVER_VERSION = "0.3"
+DRIVER_VERSION = "0.4"
+
+if weewx.__version__ < "3":
+    raise weewx.UnsupportedFeature("weewx 3 is required, found %s" %
+                                   weewx.__version__)
 
 def logmsg(dst, msg):
     syslog.syslog(dst, 'wlink: %s' % msg)
@@ -77,13 +82,17 @@ class WeatherLink(weewx.drivers.AbstractDevice):
     """
 
     def __init__(self, **stn_dict):
+        loginf("version is %s" % DRIVER_VERSION)
         self.username = stn_dict['username']
         self.password = stn_dict['password']
         self.poll_interval = float(stn_dict.get('poll_interval', 60))
         self.max_tries = int(stn_dict.get('max_tries', 5))
         self.retry_wait = int(stn_dict.get('retry_wait', 30))
+        self._archive_interval = stn_dict.get('archive_interval', None)
+        if self._archive_interval is not None:
+            self._archive_interval = int(self._archive_interval)
+            loginf("archive interval is %s seconds" % self._archive_interval)
         loginf("polling interval is %s" % self.poll_interval)
-        self._archive_interval = None
 
     @property
     def hardware_name(self):
@@ -91,6 +100,7 @@ class WeatherLink(weewx.drivers.AbstractDevice):
 
     @property
     def archive_interval(self):
+        # weewx wants the archive interval in seconds
         if self._archive_interval is None:
             self._archive_interval = self.download_archive_interval() * 60
         return self._archive_interval
